@@ -180,7 +180,7 @@ class ComplexType(object):
 				typeobj = self._createAttributeType(element)
 				setattr(self,attr,typeobj)
 
-	def toXML(self,name=None):
+	def toXML(self,name=None,method=''):
 		""" Method that creates the XML document for the instance of python class.
 		    Return a string with the xml document.
 		 """
@@ -190,6 +190,7 @@ class ComplexType(object):
 			nameroot = self.__class__.__name__
 		else:
 			nameroot = name
+		nameroot += method
 
 		xml = '<%s>'%nameroot
 		default_attr = dir(type('default',(object,),{}))
@@ -248,7 +249,7 @@ class ComplexType(object):
 
 				if ltype.count(self._elementInput.getName()) == 0:
 					ltype.append(self._elementInput.getName())
-					complextype.append(element._generateXSD())
+					complextype.append(element._generateXSD(ltype=[]))
 				
 				xsd += '<%s:element name="%s" type="tns:%s"/>'%(namespace,nameinstance,element.getName())			
 			elif inspect.isclass(element) and issubclass(element,ComplexType): 
@@ -256,12 +257,12 @@ class ComplexType(object):
 				
 				if ltype.count(element.getName()) == 0:
 					ltype.append(element.getName())
-					complextype.append(element._generateXSD())
+					complextype.append(element._generateXSD(ltype=[]))
 				
 				xsd += '<%s:element name="%s" type="tns:%s"/>'%(namespace,nameinstance,element.getName())			
 			elif isinstance(element,ArrayProperty):
 				if isinstance(element[0],ComplexType) or issubclass(element[0],ComplexType):
-					complextype.append(element[0]._generateXSD())
+					complextype.append(element[0]._generateXSD(ltype=[]))
 					xsd += '<%s:element name="%s" type="tns:%s" maxOccurs="unbounded"/>'%(namespace,key,element[0].__name__)	
 				else:
 					typeelement = createPythonType2XMLType(element[0].__name__)
@@ -272,7 +273,7 @@ class ComplexType(object):
 
 					if ltype.count(element[0].__name__) == 0:
 						ltype.append(element[0].__name__)
-						complextype.append(element[0]._generateXSD())
+						complextype.append(element[0]._generateXSD(ltype=[]))
 					
 					xsd += '<%s:element name="%s" type="tns:%s" maxOccurs="unbounded"/>'%(namespace,key,element[0].__name__)	
 				else:
